Linux
=====


Debian
------

Newer versions of Debian are supported. In fact, riot develops on a healthy mix of Debian Testing/Unstable/Experimental.

Ubuntu
------

Mostly the same as with Debian, that is why this is only a link to Debian platform specifics.
